@@ -119,7 +119,7 @@ else:
     WVD = weakref.WeakValueDictionary
 
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 API_VERSION = 4
@@ -589,6 +589,9 @@ class XYMEClient:
         self._dag_cache[dag_uri] = res
         return res
 
+    def get_blob_handle(self, uri: str, is_full: bool = False) -> 'BlobHandle':
+        return BlobHandle(self, uri, is_full=is_full)
+
     def get_node_defs(self) -> Dict[str, NodeDefInfo]:
         self._maybe_refresh()
         if self._node_defs is not None:
